% --- Source file: man/trans.Rd ---
\name{badge}
\alias{badge}
\title{
Bayesian model for Detecting Gene Environment interaction}
\description{
A flexible Bayesian model for studying gene-environment interaction.
}
\usage{
badge(data, cc.var, exposure.var, group.var, out.dir, op=NULL)
}
\arguments{
  \item{data}{Data frame containing the disease status, exposure variable, group variable and possibly covariates.}
  \item{cc.var}{Variable name for the disease status. This variable should be coded as 0 for no disease 
               and 1 for disease.}
  \item{exposure.var}{Variable name for the exposure. This variable should be numerically coded.}
  \item{group.var}{Variable name for the groups. This variable should be coded as integers from 1 to the number of groups.}
  \item{out.dir}{Directory where the output files will be written.}
  \item{op}{List of options. See \code{details} for all possible options.}
}
\value{
  The returned value is NULL. All output files are written to \code{out.dir}.
}
\details{
  Then input data should only contain finite values for the variables to be used in the analysis.

 \bold{Options list:} \cr

 Below are the names for the options list \code{op}. All names have default values
         if they are not specified.
  \itemize{
  \item \code{sim.mat} A matrix defining the similarity between groups. This matrix must be symmetric with zeros on the main diagonal.
                      The ith row and jth column of this matrix refers to groups i and j.
                      The default is a matrix of zeros. 
  \item \code{covars} Character vector of variable names to be used as covariates.
                      Example: \code{covars=c("x1", "x2", "x3")}.
                      The default is that no covariates will be used in the analysis. 
  \item \code{out.string} Character string to be appended to the output file names. The default is "". 
  \item \code{n_iter} The number of iterations. The default is 200000.
  \item \code{n_sep_out} Integer specifiying output to be written every \code{n_sep_out} iteration(s). The default is 1.
  \item \code{k_max} Maximum number of clusters. The default is 2. 
  \item \code{random_seed} Positive integer. The default is 12345. 
  \item \code{w_m} Number of auxiliary samples for updating the interaction parameter. The default is 50.
  \item \code{update_prop} Proportion of groups to be updated when updating the allocation vector. The default is 1.0.
  \item \code{update_prop_w} Proportion of groups to be updated when updating the auxiliary sample. The default is 1.0.
  \item \code{method} 0 (uniform) or 1 (normal) for the distribution of alpha, beta, and tao. The default is 0.
  \item \code{alpha_min} Minimum value for each alpha when \code{method} = 0. The default is -4.
  \item \code{alpha_max} Maximum value for each alpha when \code{method} = 0. The default is 4. 
  \item \code{alpha_mu} Mean parameter for each alpha when \code{method} = 1. The default is 0.
  \item \code{alpha_sigma2}  Variance parameter for each alpha when \code{method} = 1. The default is 4. 
  \item \code{beta_min} Minimum value for each beta when \code{method} = 0. The default is -4.
  \item \code{beta_max} Maximum value for each beta when \code{method} = 0. The default is 4. 
  \item \code{beta_mu} Mean parameter for each beta when \code{method} = 1. The default is 0.
  \item \code{beta_sigma2}  Variance parameter for each beta when \code{method} = 1. The default is 4. 
  \item \code{tao_min} Vector of minimum values for each tao (covariate) when \code{method} = 0. The default is -4.
  \item \code{tao_max} Vector of maximum values for each tao (covariate) when \code{method} = 0. The default is 4. 
  \item \code{tao_mu} Vector of mean parameters for each tao (covariate) when \code{method} = 1. The default is 0.
  \item \code{tao_sigma2}  Vector of variance parameters for each tao (covariate) when \code{method} = 1. The default is 4. 
  \item \code{method_psi} 0 (uniform), 1 (gamma), or 2 (discrete) for the distribution of psi. The default is 0.
  \item \code{psi_file} A 3-column file of psi grid points for \code{method_psi} = 2. Column 1 is the value of psi, column 2
                        is the probability of the grid point, and column 3 is the normalized value.
                        This file must be space delimited and not contain a header of column names.
                        This file can be created be calling \code{run_SAMC}.
                        The default is NULL.
  \item \code{psi_min} Minimum value of the interaction parameter. The default is 0.
  \item \code{psi_max} Maximum value of the interaction parameter. The default is 1.2. 
  \item \code{sigma2_alpha} Variance of a normal distribution with mean 0 used to update alpha. The default is 0.005. 
  \item \code{sigma2_beta} Variance of a normal distribution with mean 0 used to update beta. The default is 0.005. 
  \item \code{sigma2_tao} Variance of a normal distribution with mean 0 used to update tao. The default is 0.005. 
  \item \code{sigma2_psi} Variance of a normal distribution with mean 0 used to update psi. The default is 0.02.

  } % END: itemize

  \bold{Output files:} \cr

 Below are the descriptions of the output files. Each line of output is written once every \code{n_sep_out} iterations.
  \itemize{
  \item \code{out_psi} Estimate of the psi interaction parameter
  \item \code{out_alpha} Estimates of the alpha parameters
  \item \code{out_beta} Estimates of the beta parameters
  \item \code{out_alloc_z} Cluster number for each group
  \item \code{out_dev_i} Deviance
  \item \code{out_tao} Created only if there were covariates used in the analysis.
  } % END: itemize


}
\seealso{\code{\link{define.NB.geno}} \code{\link{run_SAMC}}}
\author{Kai Yu}
\examples{

  set.seed(123)
  n    <- 100
  cc   <- rbinom(n, 1, 0.5)
  x    <- rbinom(n, 1, 0.5)
  grp  <- sample(1:20, n, replace=TRUE) 
  data <- data.frame(cc, x, grp)
  dir  <- "K:/bayesian/R_package/temp/"

  # Not run  
  #badge(data, "cc", "x", "grp", dir)

  # Add some covariates
  ncov <- 3
  for (i in 1:ncov) data[, paste("cov", i, sep="")] <- runif(n)

  # Define the options list. See above for all possible options.
  op <- list(covars=c("cov1", "cov2", "cov3"))

  # Not run
  #badge(data, "cc", "x", "grp", dir, op=op)

  # For method_psi = 2 and number of clusters = 4
  k_max <- 4
  op <- list(k_max=k_max, clusters=k_max)

  # Create a file of grid points for psi
  #run_SAMC(data, "cc", "x", "grp", dir, op=op)

  op$method_psi <- 2
  op$psi_file <- paste(dir, "psi_grid_4.txt", sep="")
  #badge(data, "cc", "x", "grp", dir, op=op)
}